<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>EditShare</name>
    <message>
        <location filename="../editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>&amp;Emër</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="30"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>&amp;Shteg</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Po</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="56"/>
        <source>No</source>
        <translation>Jo</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>&amp;Koment</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation>Mysa&amp;firë OK</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation>Të drejta hyrjeje për përdorues të vlefshëm</translation>
    </message>
    <message>
        <location filename="../editshare.cpp" line="46"/>
        <source>Select directory to share</source>
        <translation>Përzgjidhni drejtori për ndarje</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation>&amp;Pjesë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Pjesë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;S’u gjetën pjesë përdoruesi samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation>&amp;Hiqe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <location filename="../mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation>&amp;Shto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>&amp;Përpunoni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Shteg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Koment</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>Leje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation>Mysafirë OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>&amp;Përdorues</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;S’u gjetën pjesë përdoruesi samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>&amp;Fjalëkalim</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <location filename="../mainwindow.cpp" line="311"/>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation>&amp;Aktivizo Nisje të Vetvetishme të Samba-s</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <location filename="../mainwindow.cpp" line="288"/>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Star&amp;t Samba</source>
        <translation>&amp;Nis Samba-n</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation>Shërbimi i vetënisjes së Samba-s është i çaktivizuar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Samba is running</source>
        <translation>Samba po xhiron</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>Mbi këtë aplikacion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation>&amp;Mbi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>Display help </source>
        <translation>Shfaq ndihmën </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>&amp;Help</source>
        <translation>&amp;Ndihmë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Alt+H</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Mbylle aplikacionin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>&amp;Close</source>
        <translation>&amp;Mbylle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <location filename="../mainwindow.cpp" line="98"/>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="274"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="412"/>
        <location filename="../mainwindow.cpp" line="416"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="428"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <location filename="../mainwindow.cpp" line="464"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <location filename="../mainwindow.cpp" line="520"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>Error, could not add share. Empty share name</source>
        <translation>Gabim, s’u shtua dot pjesë. Emër i zbrazët pjese</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Path: %1 doesn&apos;t exist.</source>
        <translation>Shteg: %1 s’ekziston.</translation>
    </message>
    <message>
        <source>Everyone</source>
        <translation type="vanished">Gjithkush</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <source>Yes</source>
        <translation>Po</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>Could not add share. Error message:

%1</source>
        <translation>S’u shtua dot pjesë. Mesazh gabimi:

%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Error listing users</source>
        <translation>Gabim në shfaqje përdoruesish</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>&amp;Deny</source>
        <translation>&amp;Hidhe poshtë</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>&amp;Read Only</source>
        <translation>Vetëm &amp;Lexim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="185"/>
        <source>&amp;Full Access</source>
        <translation>Hyrje e &amp;Plotë</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>Error listing shares</source>
        <translation>Gabim në shfaqje pjesësh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation>Përdoruesi juaj s’i përket grupit “sambashare”  nëse sapo e instaluar aplikacionin, mund të doni të rinisni sistemin, së pari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Sto&amp;p Samba</source>
        <translation>N&amp;dale Samba-n</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>Samba is not running</source>
        <translation>Samba s’është në punë</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Samba not installed</source>
        <translation>Samba s’është e instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation>&amp;Çaktivizo Nisje të Vetvetishme të Samba-s</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>About %1</source>
        <translation>Mbi %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>MX Samba Config</source>
        <translation>Formësim MX i Samba-s</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation>Program për formësim pjesësh dhe përdoruesish Samba.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Të drejta kopjimi (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>%1 License</source>
        <translation>Licencë %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>%1 Help</source>
        <translation>Ndihmë për %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Cannot delete user: </source>
        <translation>S’fshihet dot përdoruesi: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Enter the username and password:</source>
        <translation>Jepni emër përdoruesi dhe fjalëkalim:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Username:</source>
        <translation>Emër përdoruesi:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Password:</source>
        <translation>Fjalëkalim:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Confirm password:</source>
        <translation>Ripohoni fjalëkalimin:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>Empty username, please enter a name.</source>
        <translation>Emër i zbrazët përdoruesi, ju lutemi, jepni një emër.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation>Në sistem s’u gjet përdorues linux me përputhje, sigurohuni se dhatë një emër të vlefshëm përdoruesi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation>Fjalëkalimet nuk përputhen, ju lutemi, rijepini.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Could not add user.</source>
        <translation>S’u shtua dot përdorues.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation>Ndryshoni fjalëkalimin për &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Could not change password.</source>
        <translation>S’u ndryshua dot fjalëkalim.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Cannot delete share: </source>
        <translation>S’fshihet dot pjesë: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation>Shërbimi samba s’është në punë. Ju lutemi, nisni Samba-n para se të shtoni ose të përpunoni pjesë</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Error: trying to process permissions: </source>
        <translation>Gabim: po provohet të përpunohen leje: </translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>License</source>
        <translation type="vanished">Licencë</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Regjistër ndryshimesh</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Anuloje</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Mbylle</translation>
    </message>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Këtë program duhet ta xhironi si përdorues i thjeshtë.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>License</source>
        <translation>Licencë</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <location filename="../about.cpp" line="49"/>
        <source>Changelog</source>
        <translation>Regjistër ndryshimesh</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="62"/>
        <source>&amp;Close</source>
        <translation>&amp;Mbylle</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>You must run this program as normal user.</source>
        <translation>Këtë program duhet ta xhironi si përdorues i thjeshtë.</translation>
    </message>
</context>
</TS>
